@@ -1,5 +1,8 @@
 """OpenAPI core validation response protocols module"""
 from typing import TYPE_CHECKING
+from typing import Any
+from typing import Mapping
+from typing import Optional
 
 if TYPE_CHECKING:
     from typing_extensions import Protocol
@@ -12,7 +15,9 @@ else:
         from typing_extensions import Protocol
         from typing_extensions import runtime_checkable
 
-from werkzeug.datastructures import Headers
+from openapi_core.spec import Spec
+from openapi_core.validation.request.protocols import Request
+from openapi_core.validation.response.datatypes import ResponseValidationResult
 
 
 @runtime_checkable
@@ -43,5 +48,17 @@ class Response(Protocol):
         ...
 
     @property
-    def headers(self) -> Headers:
+    def headers(self) -> Mapping[str, Any]:
+        ...
+
+
+@runtime_checkable
+class ResponseValidator(Protocol):
+    def validate(
+        self,
+        spec: Spec,
+        request: Request,
+        response: Response,
+        base_url: Optional[str] = None,
+    ) -> ResponseValidationResult:
         ...
